@@ -5,11 +5,12 @@ Constructed Molecule
 """
 
 import logging
+
 import rdkit.Chem.AllChem as rdkit
 
-from .molecule import Molecule
 from ..atoms import AtomInfo
 from ..bonds import BondInfo
+from .molecule import Molecule
 from .utilities import get_bond_info_atom_ids, sort_bond_atoms_by_id
 
 logger = logging.getLogger(__name__)
@@ -57,10 +58,10 @@ class ConstructedMolecule(Molecule):
         tetrahedron = stk.cage.FourPlusSix((bb1, bb2))
         cage = stk.ConstructedMolecule(tetrahedron)
 
-        benzene = stk.BuildingBlock('c1ccccc1')
+        benzene = stk.host_guest.Guest(stk.BuildingBlock('c1ccccc1'))
         cage_complex = stk.host_guest.Complex(
             host=stk.BuildingBlock.init_from_molecule(cage),
-            guest=benzene,
+            guests=benzene,
         )
         cage_complex = stk.ConstructedMolecule(cage_complex)
 
