@@ -20,21 +20,23 @@ class M8L6Cube(Cage):
         import moldoc.molecule as molecule
         import stk
 
-        bb1 = stk.BuildingBlock(
-            smiles='[Pd+2]',
+        iron_atom = stk.BuildingBlock(
+            smiles='[Fe+2]',
             functional_groups=(
-                stk.SingleAtom(stk.Pd(0, charge=2))
-                for i in range(3)
+                stk.SingleAtom(stk.Fe(0, charge=2))
+                for i in range(6)
             ),
             position_matrix=[[0, 0, 0]],
         )
 
         bb2 = stk.BuildingBlock(
-            smiles=(
-                'c2cnccc2C#Cc1c(C#Cc4ccncc4)cc'
-                '(C#Cc3ccncc3)c(C#Cc5ccncc5)c1'
-            ),
+            smiles='C1=NC(C=NBr)=CC=C1',
             functional_groups=[
+                stk.SmartsFunctionalGroupFactory(
+                    smarts='[#6]~[#7X2]~[#35]',
+                    bonders=(1, ),
+                    deleters=(),
+                ),
                 stk.SmartsFunctionalGroupFactory(
                     smarts='[#6]~[#7X2]~[#6]',
                     bonders=(1, ),
@@ -43,9 +45,32 @@ class M8L6Cube(Cage):
             ],
         )
 
+        complex = stk.ConstructedMolecule(
+            topology_graph=stk.metal_complex.OctahedralDelta(
+                metals=iron_atom,
+                ligands=bb2,
+                optimizer=stk.MCHammer(),
+            ),
+        )
+
+        # Assign Bromo functional groups to the metal complex.
+        iron_oct_delta = stk.BuildingBlock.init_from_molecule(
+            molecule=complex,
+            functional_groups=[stk.BromoFactory()],
+        )
+
+        # Define building blocks.
+        bb4 = stk.BuildingBlock(
+            smiles=(
+                'C1=CC(=CC=C1C2=CC(=C(C=C2C3=CC=C(C=C3)Br)C4=CC=C(C=C'
+                '4)Br)C5=CC=C(C=C5)Br)Br'
+            ),
+            functional_groups=[stk.BromoFactory()],
+        )
+
         cage = stk.ConstructedMolecule(
             topology_graph=stk.cage.M8L6Cube(
-                building_blocks=(bb1, bb2),
+                building_blocks=(iron_oct_delta, bb4),
             ),
         )
 
@@ -72,28 +97,30 @@ class M8L6Cube(Cage):
             ),
         )
 
-    :class:`.MCHammer` optimized construction
+    :class:`.Collapser` optimized construction
 
     .. moldoc::
 
         import moldoc.molecule as molecule
         import stk
 
-        bb1 = stk.BuildingBlock(
-            smiles='[Pd+2]',
+        iron_atom = stk.BuildingBlock(
+            smiles='[Fe+2]',
             functional_groups=(
-                stk.SingleAtom(stk.Pd(0, charge=2))
-                for i in range(3)
+                stk.SingleAtom(stk.Fe(0, charge=2))
+                for i in range(6)
             ),
             position_matrix=[[0, 0, 0]],
         )
 
         bb2 = stk.BuildingBlock(
-            smiles=(
-                'c2cnccc2C#Cc1c(C#Cc4ccncc4)cc'
-                '(C#Cc3ccncc3)c(C#Cc5ccncc5)c1'
-            ),
+            smiles='C1=NC(C=NBr)=CC=C1',
             functional_groups=[
+                stk.SmartsFunctionalGroupFactory(
+                    smarts='[#6]~[#7X2]~[#35]',
+                    bonders=(1, ),
+                    deleters=(),
+                ),
                 stk.SmartsFunctionalGroupFactory(
                     smarts='[#6]~[#7X2]~[#6]',
                     bonders=(1, ),
@@ -102,10 +129,33 @@ class M8L6Cube(Cage):
             ],
         )
 
+        complex = stk.ConstructedMolecule(
+            topology_graph=stk.metal_complex.OctahedralDelta(
+                metals=iron_atom,
+                ligands=bb2,
+                optimizer=stk.MCHammer(),
+            ),
+        )
+
+        # Assign Bromo functional groups to the metal complex.
+        iron_oct_delta = stk.BuildingBlock.init_from_molecule(
+            molecule=complex,
+            functional_groups=[stk.BromoFactory()],
+        )
+
+        # Define building blocks.
+        bb4 = stk.BuildingBlock(
+            smiles=(
+                'C1=CC(=CC=C1C2=CC(=C(C=C2C3=CC=C(C=C3)Br)C4=CC=C(C=C'
+                '4)Br)C5=CC=C(C=C5)Br)Br'
+            ),
+            functional_groups=[stk.BromoFactory()],
+        )
+
         cage = stk.ConstructedMolecule(
             topology_graph=stk.cage.M8L6Cube(
-                building_blocks=(bb1, bb2),
-                optimizer=stk.MCHammer(),
+                building_blocks=(iron_oct_delta, bb4),
+                optimizer=stk.Collapser(),
             ),
         )
 
