@@ -6,15 +6,51 @@ Twenty Plus Thirty
 
 import numpy as np
 
-from ..cage import Cage
-from ..vertices import _LinearCageVertex, _NonLinearCageVertex
 from ...topology_graph import Edge
+from ..cage import Cage
+from ..vertices import LinearVertex, NonLinearVertex
 
 
 class TwentyPlusThirty(Cage):
     """
     Represents a cage topology graph.
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock(
+            smiles='BrCCBr',
+            functional_groups=[stk.BromoFactory()],
+        )
+        bb2 = stk.BuildingBlock(
+            smiles='Brc1cc(Br)cc(Br)c1',
+            functional_groups=[stk.BromoFactory()],
+        )
+        cage = stk.ConstructedMolecule(
+            topology_graph=stk.cage.TwentyPlusThirty((bb1, bb2)),
+        )
+
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cage.get_atoms(),
+                    cage.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=bond.get_order(),
+                ) for bond in cage.get_bonds()
+            ),
+        )
+
     Nonlinear building blocks with three functional groups are
     required for this topology.
 
@@ -37,163 +73,163 @@ class TwentyPlusThirty(Cage):
     # Source: http://tinyurl.com/h2dl949
     _phi = (1 + np.sqrt(5))/2
     _x = 1.5
-    _vertex_prototypes = (
-        _NonLinearCageVertex(0, [_x*_phi, 0.0, _x/_phi]),
-        _NonLinearCageVertex(1, [_x*-_phi, 0.0, _x/_phi]),
-        _NonLinearCageVertex(2, [_x*-_phi, 0.0, _x/-_phi]),
-        _NonLinearCageVertex(3, [_x*_phi, 0.0, _x/-_phi]),
+    _non_linears = (
+        NonLinearVertex(0, [_x*_phi, 0.0, _x/_phi]),
+        NonLinearVertex(1, [_x*-_phi, 0.0, _x/_phi]),
+        NonLinearVertex(2, [_x*-_phi, 0.0, _x/-_phi]),
+        NonLinearVertex(3, [_x*_phi, 0.0, _x/-_phi]),
 
-        _NonLinearCageVertex(4, [_x/_phi, _x*_phi, 0.0]),
-        _NonLinearCageVertex(5, [_x/_phi, _x*-_phi, 0.0]),
-        _NonLinearCageVertex(6, [_x/-_phi, _x*-_phi, 0.0]),
-        _NonLinearCageVertex(7, [_x/-_phi, _x*_phi, 0.0]),
-        _NonLinearCageVertex(8, [0.0, _x/_phi, _x*_phi]),
-        _NonLinearCageVertex(9, [0.0, _x/_phi, _x*-_phi]),
-        _NonLinearCageVertex(10, [0.0, _x/-_phi, _x*-_phi]),
-        _NonLinearCageVertex(11, [0.0, _x/-_phi, _x*_phi]),
+        NonLinearVertex(4, [_x/_phi, _x*_phi, 0.0]),
+        NonLinearVertex(5, [_x/_phi, _x*-_phi, 0.0]),
+        NonLinearVertex(6, [_x/-_phi, _x*-_phi, 0.0]),
+        NonLinearVertex(7, [_x/-_phi, _x*_phi, 0.0]),
+        NonLinearVertex(8, [0.0, _x/_phi, _x*_phi]),
+        NonLinearVertex(9, [0.0, _x/_phi, _x*-_phi]),
+        NonLinearVertex(10, [0.0, _x/-_phi, _x*-_phi]),
+        NonLinearVertex(11, [0.0, _x/-_phi, _x*_phi]),
 
-        _NonLinearCageVertex(12, [_x, _x, _x]),
-        _NonLinearCageVertex(13, [_x, -_x, _x]),
-        _NonLinearCageVertex(14, [-_x, -_x, _x]),
-        _NonLinearCageVertex(15, [-_x, _x, _x]),
-        _NonLinearCageVertex(16, [-_x, _x, -_x]),
-        _NonLinearCageVertex(17, [_x, _x, -_x]),
-        _NonLinearCageVertex(18, [_x, -_x, -_x]),
-        _NonLinearCageVertex(19, [-_x, -_x, -_x]),
+        NonLinearVertex(12, [_x, _x, _x]),
+        NonLinearVertex(13, [_x, -_x, _x]),
+        NonLinearVertex(14, [-_x, -_x, _x]),
+        NonLinearVertex(15, [-_x, _x, _x]),
+        NonLinearVertex(16, [-_x, _x, -_x]),
+        NonLinearVertex(17, [_x, _x, -_x]),
+        NonLinearVertex(18, [_x, -_x, -_x]),
+        NonLinearVertex(19, [-_x, -_x, -_x]),
     )
 
     _vertex_prototypes = (
-        *_vertex_prototypes,
-        _LinearCageVertex.init_at_center(
+        *_non_linears,
+        LinearVertex.init_at_center(
             id=20,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[13]),
+            vertices=(_non_linears[0], _non_linears[13]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=21,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[12]),
+            vertices=(_non_linears[0], _non_linears[12]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=22,
-            vertices=(_vertex_prototypes[0], _vertex_prototypes[3]),
+            vertices=(_non_linears[0], _non_linears[3]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=23,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[14]),
+            vertices=(_non_linears[1], _non_linears[14]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=24,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[15]),
+            vertices=(_non_linears[1], _non_linears[15]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=25,
-            vertices=(_vertex_prototypes[1], _vertex_prototypes[2]),
+            vertices=(_non_linears[1], _non_linears[2]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=26,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[19]),
+            vertices=(_non_linears[2], _non_linears[19]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=27,
-            vertices=(_vertex_prototypes[2], _vertex_prototypes[16]),
+            vertices=(_non_linears[2], _non_linears[16]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=28,
-            vertices=(_vertex_prototypes[3], _vertex_prototypes[18]),
+            vertices=(_non_linears[3], _non_linears[18]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=29,
-            vertices=(_vertex_prototypes[3], _vertex_prototypes[17]),
+            vertices=(_non_linears[3], _non_linears[17]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=30,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[12]),
+            vertices=(_non_linears[4], _non_linears[12]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=31,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[7]),
+            vertices=(_non_linears[4], _non_linears[7]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=32,
-            vertices=(_vertex_prototypes[4], _vertex_prototypes[17]),
+            vertices=(_non_linears[4], _non_linears[17]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=33,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[6]),
+            vertices=(_non_linears[5], _non_linears[6]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=34,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[18]),
+            vertices=(_non_linears[5], _non_linears[18]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=35,
-            vertices=(_vertex_prototypes[5], _vertex_prototypes[13]),
+            vertices=(_non_linears[5], _non_linears[13]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=36,
-            vertices=(_vertex_prototypes[6], _vertex_prototypes[14]),
+            vertices=(_non_linears[6], _non_linears[14]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=37,
-            vertices=(_vertex_prototypes[6], _vertex_prototypes[19]),
+            vertices=(_non_linears[6], _non_linears[19]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=38,
-            vertices=(_vertex_prototypes[7], _vertex_prototypes[15]),
+            vertices=(_non_linears[7], _non_linears[15]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=39,
-            vertices=(_vertex_prototypes[7], _vertex_prototypes[16]),
+            vertices=(_non_linears[7], _non_linears[16]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=40,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[11]),
+            vertices=(_non_linears[8], _non_linears[11]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=41,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[12]),
+            vertices=(_non_linears[8], _non_linears[12]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=42,
-            vertices=(_vertex_prototypes[8], _vertex_prototypes[15]),
+            vertices=(_non_linears[8], _non_linears[15]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=43,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[10]),
+            vertices=(_non_linears[9], _non_linears[10]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=44,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[17]),
+            vertices=(_non_linears[9], _non_linears[17]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=45,
-            vertices=(_vertex_prototypes[9], _vertex_prototypes[16]),
+            vertices=(_non_linears[9], _non_linears[16]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=46,
-            vertices=(_vertex_prototypes[10], _vertex_prototypes[18]),
+            vertices=(_non_linears[10], _non_linears[18]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=47,
-            vertices=(_vertex_prototypes[10], _vertex_prototypes[19]),
+            vertices=(_non_linears[10], _non_linears[19]),
         ),
 
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=48,
-            vertices=(_vertex_prototypes[11], _vertex_prototypes[14]),
+            vertices=(_non_linears[11], _non_linears[14]),
         ),
-        _LinearCageVertex.init_at_center(
+        LinearVertex.init_at_center(
             id=49,
-            vertices=(_vertex_prototypes[11], _vertex_prototypes[13])),
+            vertices=(_non_linears[11], _non_linears[13])),
     )
 
     _edge_prototypes = (
