@@ -28,19 +28,20 @@ stk.molecular.topology_graphs.cof.periodic_linkerless_honeycomb\
 
 import itertools as it
 from collections import Counter
-import numpy as np
 from functools import partial
 from operator import getitem
 
-from ..topology_graph import (
-    TopologyGraph,
-    NullOptimizer,
-    EdgeGroup,
-    PeriodicConstructionResult,
-)
-from .vertices import _UnaligningVertex
-from .edge import _CofEdge
+import numpy as np
+
 from ...reactions import GenericReactionFactory
+from ..topology_graph import (
+    EdgeGroup,
+    NullOptimizer,
+    PeriodicConstructionResult,
+    TopologyGraph,
+)
+from .edge import CofEdge
+from .vertices import UnaligningVertex
 
 
 class UnoccupiedVertexError(Exception):
@@ -96,6 +97,39 @@ class Cof(TopologyGraph):
             topology_graph=stk.cof.Honeycomb((bb1, bb2), (3, 3, 1)),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('BrCCBr', [stk.BromoFactory()])
+        bb2 = stk.BuildingBlock('BrCC(CBr)CBr', [stk.BromoFactory()])
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.Honeycomb((bb1, bb2), (3, 3, 1)),
+        )
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cof.get_atoms(),
+                    cof.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=(
+                        1
+                        if bond.get_order() == 9
+                        else bond.get_order()
+                    ),
+                ) for bond in cof.get_bonds()
+            ),
+        )
+
     *Suggested Optimization*
 
     For :class:`.Cof` topologies, it is recommend to use the
@@ -130,6 +164,46 @@ class Cof(TopologyGraph):
             ),
         )
 
+    .. moldoc::
+
+        import moldoc.molecule as molecule
+        import stk
+
+        bb1 = stk.BuildingBlock('BrCCBr', [stk.BromoFactory()])
+        bb2 = stk.BuildingBlock('BrCC(CBr)CBr', [stk.BromoFactory()])
+
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.Honeycomb(
+                building_blocks=(bb1, bb2),
+                lattice_size=(3, 3, 1),
+                # Setting scale_steps to False tends to lead to a
+                # better structure.
+                optimizer=stk.Collapser(scale_steps=False),
+            ),
+        )
+        moldoc_display_molecule = molecule.Molecule(
+            atoms=(
+                molecule.Atom(
+                    atomic_number=atom.get_atomic_number(),
+                    position=position,
+                ) for atom, position in zip(
+                    cof.get_atoms(),
+                    cof.get_position_matrix(),
+                )
+            ),
+            bonds=(
+                molecule.Bond(
+                    atom1_id=bond.get_atom1().get_id(),
+                    atom2_id=bond.get_atom2().get_id(),
+                    order=(
+                        1
+                        if bond.get_order() == 9
+                        else bond.get_order()
+                    ),
+                ) for bond in cof.get_bonds()
+            ),
+        )
+
     *Accessing the Periodic Information*
 
     When building periodic :class:`.Cof` instances, the periodic
@@ -413,11 +487,16 @@ class Cof(TopologyGraph):
         for building_block, vertices in clone.items():
             # Building blocks with 1 placer, cannot be aligned and
             # must therefore use an UnaligningVertex.
-            if len(set(building_block.get_placer_ids())) == 1:
-                clone[building_block] = tuple(map(
-                    _UnaligningVertex,
-                    vertices,
-                ))
+            if building_block.get_num_placers() == 1:
+                clone[building_block] = tuple(
+                    UnaligningVertex(
+                        id=v.get_id(),
+                        position=v.get_position(),
+                        aligner_edge=v.get_aligner_edge(),
+                        cell=v.get_cell(),
+                    )
+                    for v in vertices
+                )
 
         return clone
 
@@ -618,7 +697,7 @@ class Cof(TopologyGraph):
                 dim >= 0 and dim < max_dim
                 for dim, max_dim in dims
             )
-            edge_clones.append(_CofEdge(
+            edge_clones.append(CofEdge(
                 parent_id=edge.get_id(),
                 id=id_,
                 vertex1=lattice[x][y][z][edge.get_vertex1_id()],
